#
# spec file for package patterns-gnome
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           patterns-gnome
Version:        20250310
Release:        2.1
Summary:        Patterns for Installation (Gnome)
License:        MIT
Group:          Metapackages
URL:            https://github.com/openSUSE/patterns
Source0:        %{name}-rpmlintrc
BuildRequires:  patterns-rpm-macros

%description
This is an internal package that is used to create the patterns as part
of the installation source setup.  Installation of this package does
not make sense.

This particular package contains all the Gnome patterns.









################################################################################
%package gnome
%pattern_graphicalenvironments
Summary:        GNOME Desktop Environment (Wayland)
Group:          Metapackages
Provides:       pattern() = gnome
Provides:       pattern-icon() = pattern-gnome-wayland
Provides:       pattern-order() = 1010
Provides:       pattern-visible()
Requires:       gnome-session-wayland
Requires:       pattern() = gnome_basic

%description gnome
The GNOME desktop environment is an intuitive and attractive desktop for users.
This pattern installs components for GNOME to run with Wayland and X11 technologies.

%files gnome
%dir %{_docdir}/patterns
%{_docdir}/patterns/gnome.txt

################################################################################

%if 0%{?is_opensuse}
%package gnome_x11
%pattern_graphicalenvironments
Summary:        GNOME Desktop Environment (X11)
Group:          Metapackages
Provides:       pattern() = gnome_x11
Provides:       pattern-icon() = pattern-gnome-xorg
Provides:       pattern-order() = 1020
Provides:       pattern-visible()
Requires:       gnome-session-xsession
Requires:       pattern() = gnome_basic
Requires:       pattern() = x11

################################################################################

%description gnome_x11
The GNOME desktop environment is an intuitive and attractive desktop for users.
This pattern installs a full featured GNOME desktop environment, including
Office suite, E-Mail client, Web Browser, File Manager, running with X11
technology.

%files gnome_x11
%dir %{_docdir}/patterns
%{_docdir}/patterns/gnome_x11.txt
%endif

################################################################################

%package gnome_basic
%pattern_graphicalenvironments
Summary:        GNOME Desktop Environment (Basic)
Group:          Metapackages
Provides:       pattern() = gnome_basic
Provides:       pattern-icon() = pattern-gnome
Provides:       pattern-order() = 1000
Provides:       pattern-visible()
Requires:       gsettings-backend-dconf
Requires:       pattern() = basesystem
Requires:       pattern() = gnome_basis
Recommends:     pattern() = enhanced_base
# bsc#1065146
%if 0%{?sle_version} && 0%{?sle_version} < 16000
Recommends:     gedit
%else
Recommends:     gnome-text-editor
%endif
Recommends:     gnome-calculator %dnl bsc#1063156
Recommends:     gnome-software
Recommends:     gnome-system-monitor
Recommends:     gnome-tweaks %dnl bnc#859494 bsc#1065790
Recommends:     nautilus-share
Recommends:     pinentry-gnome3
# bsc#1164858 bsc#1081584
# - only in Leap and SLE as we don't want to install gnome-packagekit by
#   default on TW
%if 0%{?suse_version} != 01600
Recommends:     gnome-packagekit
%endif
%if !0%{?is_opensuse}
Obsoletes:      patterns-sles-gnome-basic
%endif
%if 0%{?is_opensuse}
Recommends:     pattern() = gnome_games
Recommends:     pattern() = gnome_utilities
Recommends:     pattern() = imaging
Recommends:     pattern() = multimedia
%endif
Recommends:     pattern() = gnome_internet
# #545263
Requires:       seahorse
%if 0%{?is_opensuse}
Recommends:     totem
Recommends:     pattern() = gnome_imaging
Recommends:     pattern() = office
Recommends:     pattern() = x11_yast
%endif
#
# Official upstream
#
# bijiben == gnome-notes
# Disable (temp?) gnome-notes while we wait for upstream to fix the now 6 months old bug with it crashing in its search-provider
#Recommends:     bijiben
# no longer need to hard require cheese for g-c-c user panel
Recommends:     cheese
Recommends:     dconf-editor
%if 0%{?suse_version} >= 01600
Recommends:     gnome-papers
%else
Recommends:     evince
%endif
Recommends:     evolution
Recommends:     evolution-ews
Recommends:     gnome-backgrounds
Recommends:     gnome-bluetooth
Recommends:     gnome-characters  %dnl bsc#1069699
Recommends:     gnome-clocks
Recommends:     gnome-contacts %dnl bsc#1069699
Recommends:     gnome-control-center-color
Recommends:     gnome-control-center-goa
Recommends:     gnome-disk-utility %dnl boo#554954
Recommends:     gnome-remote-desktop
Recommends:     nautilus-sendto
Recommends:     noto-sans-cjk-fonts
Recommends:     orca
%if 0%{?suse_version} < 01600 && !0%{?is_opensuse}
Recommends:     pidgin %dnl bsc#1065191
Recommends:     planner
%endif
Recommends:     python3-speechd
Recommends:     speech-dispatcher
Recommends:     systemd-icon-branding
Recommends:     tinysparql %dnl boo#608156
Recommends:     zenity
Suggests:       pattern() = documentation
%if 0%{?is_opensuse}
Provides:       patterns-openSUSE-gnome = %{version}
Obsoletes:      patterns-openSUSE-gnome < %{version}
%else
Provides:       patterns-sled-Default
Obsoletes:      patterns-sled-Default < %{version}
%endif
%if 0%{?is_opensuse}
Recommends:     vinagre
%else
Recommends:     remmina
%endif
%if !0%{?is_opensuse}
Recommends:     gnome-initial-setup
%endif
%if !0%{?is_opensuse}
Recommends:     gutenprint %dnl bsc#1075136
%endif
#
# #447627
%if !0%{?is_opensuse}
Recommends:     gnome-user-share %dnl bsc#1087222
%else
Requires:       gnome-user-share
%endif
%if 0%{?is_opensuse}
#
# Official upstream
#
Recommends:     gnome-console
Recommends:     baobab
Recommends:     gcr-viewer
Recommends:     gnome-characters
Recommends:     gnome-contacts
Recommends:     gnome-logs
Recommends:     gnome-maps
Recommends:     gnome-system-monitor
%if 0%{?sle_version} && 0%{?sle_version} < 16000
Recommends:     gedit
%else
Recommends:     gnome-text-editor
%endif
#
# While running a GNOME3 session, it's nice to have the GNOME3 related pinentry
# for proper gpg2 integration
#
Recommends:     pinentry-gnome3
Recommends:     sushi
#
# Packages that really make sense
#
# Tool for advanced configuration of printers
Recommends:     system-config-printer
Suggests:       gnome-color-manager %dnl bnc#698250
%else
Recommends:     NetworkManager-openconnect-gnome
# bsc#1065148
Recommends:     NetworkManager-openvpn-gnome
Recommends:     NetworkManager-pptp-gnome
Recommends:     desktop-data-SLE-extra
%endif
Recommends:     malcontent-control
# openSUSE welcome is our 'welcome app'
%if 0%{?is_opensuse}
Recommends:     opensuse-welcome
%endif

%description gnome_basic
The GNOME desktop environment is an intuitive and attractive desktop for users.
This pattern installs GNOME desktop environment with only essential graphical
applications installed (File Manager, Web Browser).

%files gnome_basic
%dir %{_docdir}/patterns
%{_docdir}/patterns/gnome_basic.txt

################################################################################

%package gnome_basis
%pattern_graphicalenvironments
Summary:        GNOME Base System
Group:          Metapackages
Provides:       pattern() = gnome_basis
Provides:       pattern-icon() = pattern-gnome
%if 0%{?is_opensuse}
Provides:       patterns-openSUSE-gnome_basis = %{version}
Obsoletes:      patterns-openSUSE-gnome_basis < %{version}
%endif
Requires:       gdm
Requires:       gnome-session
# ensure we have default fonts always installed
Requires:       adobe-sourcecodepro-fonts
Requires:       adwaita-fonts
# from data/COMMON-DESKTOP
Recommends:     desktop-data
Recommends:     desktop-file-utils
#
# Now the real packages
#
# #332596
Recommends:     gnome-keyring-pam
# implied by gnome-keyring-pam
#Recommends:     gnome-keyring
# implied by gdm
#Requires: gnome-shell
#Requires: gnome-settings-daemon
# implied by gnome-shell
#Requires:       gnome-control-center
# Accessability is not an option, and performance issues if its missing (boo#1204564)
Requires:       at-spi2-core
%if 0%{?suse_version} < 1600
# boo#1090117
Recommends:     gnome-shell-classic
%endif
Recommends:     gnome-console
Recommends:     gnome-extensions
# bnc#879466
Recommends:     gnome-user-docs
Recommends:     gpgme
# we need something for xdg-su
Recommends:     libgnomesu
Recommends:     nautilus
Recommends:     polkit-default-privs

%if 0%{?suse_version} > 1500
# Pipewire is the default sound server
Recommends:     pipewire
Recommends:     pipewire-pulseaudio
%else
# Pulseaudio is the default sound server
Recommends:     pulseaudio-module-gsettings
Recommends:     pulseaudio-module-x11
%endif

# #509829
Recommends:     xdg-user-dirs-gtk
Recommends:     yelp
#
# Low-level parts that we need
#
# bnc#430161
Recommends:     NetworkManager
%if 0%{?is_opensuse}
Recommends:     canberra-gtk-play
%endif
%if 0%{?is_opensuse}
Recommends:     avahi
#
# Branding
#
# #591535
Suggests:       gdm-branding-openSUSE
Suggests:       gio-branding-openSUSE
Suggests:       gtk3-branding-openSUSE
Suggests:       hicolor-icon-theme-branding-openSUSE
%endif

%description gnome_basis
Base packages for the GNOME desktop environment.

%files gnome_basis
%dir %{_docdir}/patterns
%{_docdir}/patterns/gnome_basis.txt

################################################################################

################################################################################

%if 0%{?is_opensuse}
%package devel_gnome
%pattern_development
Summary:        GNOME Development
Group:          Metapackages
Provides:       patterns-openSUSE-devel_gnome = %{version}
Provides:       pattern() = devel_gnome
Provides:       pattern-icon() = pattern-gnome-devel
Provides:       pattern-order() = 3160
Provides:       pattern-visible()
Obsoletes:      patterns-openSUSE-devel_gnome < %{version}
Requires:       pattern() = devel_C_C++
Requires:       pattern() = gnome_basis
Recommends:     cairo-devel
Recommends:     clutter-devel
Recommends:     clutter-gst-devel
Recommends:     clutter-gtk-devel
Recommends:     evolution-data-server-devel
Recommends:     gdk-pixbuf-devel
Recommends:     glib2-devel
# Build tools
Recommends:     gnome-common
Recommends:     gnome-online-accounts-devel
Recommends:     gobject-introspection-devel
Recommends:     gtk-doc
Recommends:     gtk3-devel
Recommends:     gtksourceview-devel
Recommends:     intltool
Recommends:     itstool
Recommends:     json-glib-devel
Recommends:     libcanberra-devel
Recommends:     libgdata-devel
Recommends:     libgnome-desktop-3-devel
Recommends:     libgnome-keyring-devel
Recommends:     libgsf-devel
Recommends:     libgtop-devel
Recommends:     libgweather-devel
Recommends:     libnotify-devel
Recommends:     librsvg-devel
Recommends:     libsoup-devel
Recommends:     libwebkitgtk-devel
Recommends:     libwnck-devel
Recommends:     pango-devel
Recommends:     tinysparql-devel
Recommends:     vala
Recommends:     vte-devel
Recommends:     yelp-tools

%description devel_gnome
GNOME development packages.

%files devel_gnome
%dir %{_docdir}/patterns
%{_docdir}/patterns/devel_gnome.txt
%endif

################################################################################

%if 0%{?is_opensuse}
%package gnome_games
%pattern_gnomedesktop
Summary:        GNOME Games
Group:          Metapackages
Provides:       patterns-openSUSE-gnome_games = %{version}
Provides:       pattern() = gnome_games
Provides:       pattern-extends() = games
Provides:       pattern-icon() = pattern-gnome
Provides:       pattern-order() = 2100
Obsoletes:      patterns-openSUSE-gnome_games < %{version}
Recommends:     gnome-chess
Recommends:     gnome-mahjongg
Recommends:     gnome-mines
Recommends:     gnome-sudoku
Recommends:     gnuchess
# from data/GNOME-Games
Recommends:     iagno
Recommends:     lightsoff
Recommends:     quadrapassel
Recommends:     swell-foop
Suggests:       gnome-games-extra-data
Suggests:       phalanx
Supplements:    packageand(patterns-gnome-gnome:patterns-games-games)

%description gnome_games
GNOME Games

%files gnome_games
%dir %{_docdir}/patterns
%{_docdir}/patterns/gnome_games.txt
%endif

################################################################################

%if 0%{?is_opensuse}
%package gnome_ide
%pattern_gnomedesktop
Summary:        GNOME Integrated Development Environment
Group:          Metapackages
Provides:       patterns-openSUSE-gnome_ide = %{version}
Provides:       pattern() = gnome_ide
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-order() = 2060
Obsoletes:      patterns-openSUSE-gnome_ide < %{version}
# from data/GNOME-IDE
Recommends:     devhelp
Recommends:     gnome-builder
# from devel_ide
Suggests:       accerciser
Suggests:       glade
%if 0%{?sle_version}
Suggests:       gedit
Suggests:       gedit-plugins
%else
Suggests:       gnome-text-editor
%endif
Suggests:       ghex
Suggests:       gnome-devel-docs

%description gnome_ide
Development under GNOME

%files gnome_ide
%dir %{_docdir}/patterns
%{_docdir}/patterns/gnome_ide.txt
%endif

################################################################################

%package gnome_imaging
%pattern_gnomedesktop
Summary:        GNOME Graphics
Group:          Metapackages
Provides:       pattern() = gnome_imaging
Provides:       pattern-extends() = imaging
Provides:       pattern-icon() = package_graphics
Provides:       pattern-order() = 2140
Requires:       pattern() = gnome_basis
# from data/GNOME-IMAGE
#
# Official upstream
#
Recommends:     loupe
#
# Packages that really make sense
#
Recommends:     gnome-photos
Recommends:     simple-scan
Suggests:       gthumb
Supplements:    packageand(patterns-gnome-gnome:patterns-desktop-imaging)
%if 0%{?is_opensuse}
Provides:       patterns-openSUSE-gnome_imaging = %{version}
Obsoletes:      patterns-openSUSE-gnome_imaging < %{version}
%endif

%description gnome_imaging
Handling of digital photos and graphics

%files gnome_imaging
%dir %{_docdir}/patterns
%{_docdir}/patterns/gnome_imaging.txt

################################################################################

%package gnome_internet
%pattern_gnomedesktop
Summary:        GNOME Internet
Group:          Metapackages
Provides:       patterns-openSUSE-gnome_internet = %{version}
Provides:       pattern() = gnome_internet
Provides:       pattern-extends() = gnome
Provides:       pattern-icon() = package_network
Provides:       pattern-order() = 2420
Obsoletes:      patterns-openSUSE-gnome_internet < %{version}
Recommends:     NetworkManager-openconnect-gnome
#
# Packages that really make sense
#
Recommends:     MozillaFirefox
# bnc#533580
Recommends:     NetworkManager-openvpn-gnome
Recommends:     NetworkManager-pptp-gnome
Recommends:     NetworkManager-vpnc-gnome
Recommends:     evolution
# from data/GNOME-Internet
#
# Official upstream
#
Recommends:     polari
# bnc#530416
Recommends:     transmission-gtk
#
# Official upstream
#
# bnc#366894
Suggests:       epiphany
Suggests:       evolution-plugin-rss

%description gnome_internet
GNOME Internet Applications

%files gnome_internet
%dir %{_docdir}/patterns
%{_docdir}/patterns/gnome_internet.txt

################################################################################

%if 0%{?is_opensuse}
%package gnome_multimedia
%pattern_gnomedesktop
Summary:        GNOME Multimedia
Group:          Metapackages
Provides:       patterns-openSUSE-gnome_multimedia = %{version}
Provides:       pattern() = gnome_multimedia
Provides:       pattern-extends() = multimedia
Provides:       pattern-icon() = pattern-gnome
Provides:       pattern-order() = 2200
Obsoletes:      patterns-openSUSE-gnome_multimedia < %{version}
#
# Packages that really make sense
#
Recommends:     gnome-music
Recommends:     gstreamer-plugins-bad
#
# GStreamer magic
#
# software.openSUSE.org/codecs
Recommends:     gstreamer-plugins-base
Recommends:     gstreamer-plugins-good
Recommends:     gstreamer-plugins-libav
Recommends:     gstreamer-plugins-ugly
# bnc#445314
Recommends:     gstreamer-utils
#
# Official upstream
#
Recommends:     totem
#
# Packages that really make sense
#
Suggests:       paprefs
Suggests:       pavucontrol
Suggests:       pitivi
Supplements:    packageand(patterns-gnome-gnome:patterns-desktop-multimedia)

%description gnome_multimedia
GNOME Multimedia

%files gnome_multimedia
%dir %{_docdir}/patterns
%{_docdir}/patterns/gnome_multimedia.txt
%endif

################################################################################

%if 0%{?is_opensuse}
%package gnome_office
%pattern_gnomedesktop
Summary:        GNOME Office
Group:          Metapackages
Provides:       patterns-openSUSE-gnome_office = %{version}
Provides:       pattern() = gnome_office
Provides:       pattern-extends() = office
Provides:       pattern-icon() = pattern-gnome
Provides:       pattern-order() = 2240
Obsoletes:      patterns-openSUSE-gnome_office < %{version}
Requires:       pattern() = gnome_basis
# from data/GNOME-Office
#
# Official upstream
#
Recommends:     evolution
#
# Packages that really make sense
#
Recommends:     libreoffice-gnome
Recommends:     libreoffice-icon-theme-tango
Suggests:       evolution-ews
Supplements:    packageand(patterns-gnome-gnome:patterns-office-office)

%description gnome_office
GNOME Office

%files gnome_office
%dir %{_docdir}/patterns
%{_docdir}/patterns/gnome_office.txt
%endif

################################################################################

%if 0%{?is_opensuse}
%package gnome_utilities
%pattern_gnomedesktop
Summary:        GNOME Utilities
Group:          Metapackages
Provides:       patterns-openSUSE-gnome_utilities = %{version}
Provides:       pattern() = gnome_utilities
Provides:       pattern-extends() = gnome
Provides:       pattern-icon() = pattern-gnome
Provides:       pattern-order() = 2280
Obsoletes:      patterns-openSUSE-gnome_utilities < %{version}
Requires:       pattern() = gnome_basis
#
# Official upstream
#
# bijiben == gnome-notes
# Disable (temp?) gnome-notes while we wait for upstream to fix the now 6 months old bug with it crashing in its search-provider
#Recommends:     bijiben
Recommends:     baobab
Recommends:     cheese
Recommends:     gdk-pixbuf-thumbnailer
Recommends:     gnome-calculator
Recommends:     gnome-characters
%if 0%{?sle_version}
Recommends:     gedit
%else
Recommends:     gnome-text-editor
%endif
#
# Packages that really make sense
#
Recommends:     gnome-tweaks
Recommends:     gnome-weather
Recommends:     gsf-office-thumbnailer
Recommends:     nautilus-extension-seahorse
Recommends:     nautilus-sendto
Recommends:     rsvg-thumbnailer
Recommends:     seahorse
#
# Official upstream
#
Suggests:       eog-plugins
# #388570
Suggests:       nautilus-share
%if 0%{?sle_version}
Suggests:       gedit-plugins
%endif

%description gnome_utilities
GNOME Utilities

%files gnome_utilities
%dir %{_docdir}/patterns
%{_docdir}/patterns/gnome_utilities.txt
%endif

################################################################################

%if 0%{?is_opensuse}
%package gnome_yast
%pattern_basetechnologies
Summary:        YaST GNOME User Interfaces
Group:          Metapackages
Provides:       patterns-openSUSE-gnome_yast = %{version}
Provides:       pattern() = gnome_yast
Provides:       pattern-extends() = yast2_basis
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-order() = 1260
Obsoletes:      patterns-openSUSE-gnome_yast < %{version}
Requires:       libyui-qt-pkg
Requires:       yast2-control-center-qt
Supplements:    packageand(patterns-gnome-gnome:patterns-yast-yast2_basis)

%description gnome_yast
Graphical YaST user interfaces for the GNOME desktop.

%files gnome_yast
%dir %{_docdir}/patterns
%{_docdir}/patterns/gnome_yast.txt
%endif

################################################################################

%if 0%{?is_opensuse}
%package sw_management_gnome
%pattern_basetechnologies
Summary:        Package Management - Graphical Tools for GNOME
Group:          Metapackages
Provides:       patterns-openSUSE-sw_management_gnome = %{version}
Provides:       pattern() = sw_management_gnome
Provides:       pattern-extends() = sw_management
Provides:       pattern-icon() = pattern-generic
Provides:       pattern-order() = 1780
Obsoletes:      patterns-openSUSE-sw_management_gnome < %{version}
Requires:       pattern() = sw_management
# gnome-packagekit needed for openQA - and allows fainer grained updates than Software
Recommends:     gnome-packagekit
Recommends:     gnome-software
Supplements:    packageand(patterns-gnome-gnome_basis:patterns-base-sw_management)

%description sw_management_gnome
Package Management - Graphical Tools

%files sw_management_gnome
%dir %{_docdir}/patterns
%{_docdir}/patterns/sw_management_gnome.txt
%endif

%prep

%build

%install

mkdir -p "%{buildroot}%{_docdir}/patterns"
for i in gnome gnome_basis gnome_basic gnome_imaging gnome_internet ; do
	echo "This file marks the pattern $i to be installed." \
		>"%{buildroot}%{_docdir}/patterns/$i.txt"
done

%if 0%{?is_opensuse}
for i in devel_gnome \
    gnome_games gnome_ide gnome_x11 gnome_multimedia \
    gnome_office \
    gnome_utilities gnome_yast sw_management_gnome; do
	echo "This file marks the pattern $i to be installed." \
		>"%{buildroot}%{_docdir}/patterns/$i.txt"
done
%endif

%changelog
* Thu Apr 17 2025 Frederic Crozat <fcrozat@suse.com>
- Switch to Loupe and Papers for TW.
* Mon Apr  7 2025 Frederic Crozat <fcrozat@suse.com>
- Adaptation for SLES16:
  * Disable gnome_x11, gnome_multimedia and enable gnome_internet
    patterns
  * Always recommends NetworkManager and gnome_internet pattern.
  * no longer recommends gnome-shell-classic, pidgin, planner,
    totem packages and gnome_imaging, office and x11_yast patterns.
  * switch from gnome-terminal to GNOME Console
  * switch from gedit to GNOME Text Editor
  * switch from evince to Papers
- Hardcode adobe-sourcecodepro and adwaita fonts to ensure
  always have default fonts installed, when recommends are disabled
- No longer recommends gnome-desktop
* Mon Mar 24 2025 Dominique Leuenberger <dimstar@opensuse.org>
- Recommend gnome-console instead of gnome-terminal.
* Fri Feb 28 2025 Dominique Leuenberger <dimstar@opensuse.org>
- boo#1238067: Recommend opensuse-welcome by
  patterns-gnome-gnome_basis: this used to be pulled in by
  gnome_imaging -> imaging -> x11 -> x11_enhanced -> oS-welcome
  Since imaging was changed to not require the x11 pattern,
  opensuse-welcome has been lost in some cases.
* Wed Feb 26 2025 Dominique Leuenberger <dimstar@opensuse.org>
- Move MozillaFirefox from gnome_basis to gnome_internet. For the
  end-user this is a NO-OP, as gnome_internet is recommended by
  gnome_basis anyway, but it's more accurate.
- Drop recommends of no longer exitsing branding packages:
  gnome-control-center-branding-openSUSE,
  gnome-panel-branding-openSUSE, libsocialweb-branding-openSUSE.
- Lower gdm-branding-openSUSE, gtk2-branding-openSUSE and
  gtk3-branding-openSUSE from Recommends to Suggests: only use them
  as hints for the solver, but do not actually trigger
  installation. This is especially relevant for
  gtk2-branding-openSUSE. Being recommended means it's
  auto-installed by default, even if gtk2 would not be needed.
- Lower totem from Required to Recommended.
- No longer Recommend totem-browser-plugin, which has been removed
  from the distro in 2014.
* Wed Feb 26 2025 Dominique Leuenberger <dimstar@opensuse.org>
- Have pattern gnome_basic recommend pattern() = enhanced_base: most
  users of a desktop will want those tools. They were pulled in
  before via the recently removed imaging -> x11 -> enahnced_base.
  As x11 was removed as a dependency from the desktop-imaging
  pattern, this was lost.
* Tue Nov 12 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Replace tracker with tinysparql: tracker was renamed with GNOME
  47.
* Tue Nov 12 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Some major overhaul over the GNOME patterns: allow to properly
  have wayland or X11 decoupled from each other, stepping closer to
  a wayland-only installation.
* Thu Nov  7 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Require gnome-session-xsession in the gnome (X11) pattern
  (boo#1233064).
* Thu Oct 31 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Drop file-roller Recommends, the built in support in nautilus is
  sufficient.
- Change console to gnome-console Recommends: Use the current app
  name.
- Drop nautilus-extension-terminal Recommends: nautilus supports
  gnome-console natively.
* Tue Mar 26 2024 Yifan Jiang <yfjiang@suse.com>
- Keep gedit instead of gnome-text-editor on SLE and Leap
  (bsc#1219646).
* Tue Mar 19 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Add console as a terminal-client.
* Fri Oct 13 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Drop mousetweaks as a recommended package, it has not been needed
  for assistive technologies in a long time.
* Fri Oct  6 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Disable (temp?) gnome-notes while we wait for upstream to fix the
  now 6 months old bug with it crashing in its search-provider. See
  https://gitlab.gnome.org/GNOME/gnome-notes/-/issues/196 and
  https://bugzilla.opensuse.org/show_bug.cgi?id=1210322
* Tue Apr 25 2023 Alexandru Gabriel Bradatan <alex.bradatan85@yahoo.it>
- Delete archived applications (gnome-dictionary)
- Remove gnome-screenshot recommendation (replaced by the new
  screenshot tool in gnome-shell >= 42)
* Tue Apr 18 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Drop pidgin and planner Recommends from openSUSE, only install by
  default on SLED. Planner is no longer available on Tumbleweed.
* Fri Apr 14 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Replace gedit with gnome-text-editor as default editor. Following
  this, drop all gedit-plugins Suggests.
- Downgrade glade Recommends to Suggests in gnome_ide pattern.
* Tue Feb 21 2023 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Require xorg-x11-fonts on SLE earlier than 15-SP5 to fix
  gnome-shell starting failure (bsc#1203966)
* Fri Oct 21 2022 Richard Brown <rbrown@suse.com>
- Require at-spi2-core else risk major performance issues (boo#1204564)
* Sat Oct 15 2022 Milachew <milachew@mail.lv>
- Delete some abandoned packages.
- Replace gnome-tweak-tool to gnome-tweaks.
* Sun Sep 25 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add gnome-backgrounds Recommends to gnome-x11 pattern.
* Tue Jul  5 2022 Antonio Larrosa <alarrosa@suse.com>
- Replace pulseaudio with pipewire as the default audio server
  in TW.
* Thu Apr 28 2022 Yifan Jiang <yfjiang@suse.com>
- Enable bijiben for default installation on SLE as well
  (bsc#1192326).
* Fri Mar 25 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Recommend systemd-icon-branding by gnome_x11: try to get the
  correct branding installed, allowing to show the correct icon in
  gnome-control-center.
* Sat Feb 12 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Drop gnome-documents Recommends: Package is archived upstream.
* Wed Jan 26 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Recommend the gnome_games pattern by gnome_x11 instead of the
  generic games pattern.
* Mon Jan 24 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Do not require gnome-packagekit by gnome_x11: we have a specific
  sw_management_gnome pattern, which supplements the generic
  sw_management plus the basic gnome pattern, and that's where we
  also should (and do) recommend gnome-packagekit.
* Mon Jan 24 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Do not recommend speech-dispatcher-module-espeak: we recommend
  speech-dispatcher, the rest is handled by dependencies from the
  packages (recommends and supplements).
- No longer recommend gnome-menus: GNOME 3 is not using menu
  structures. This package is used by extension-classic, and if
  that extension is installed, gnome-menus comes in as a dep.
- Stop recommending samba: samba is the server, which makes no
  sense to be recommended by the desktop pattern.
* Sat Dec 11 2021 Dominique Leuenberger <dimstar@opensuse.org>
- No longer suggest brasero: the suggests is mainly used to add
  something onto the DVD (not installed by default). With Cd/DVD
  burning declining, less users need this and it remains available
  in the repositories.
- Drop giggle suggests: NOP, as that package does not exist
  anymore.
* Wed Sep 29 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Drop gnome-power-manager Recommends: Package is dormant upstream
  and on its way to be replaced by new features inside of
  gnome-control-center.
* Wed Jul 28 2021 Yifan Jiang <yfjiang@suse.com>
- Replace %%{is_opensuse} tags with %%{?is_opensuse} to remove
  dependency on the project defined macro.
* Fri Mar 26 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Recommend gnome-extensions for installation by basis pattern.
* Tue Jan 12 2021 Frederic Crozat <fcrozat@suse.com>
- Downgrade requires to recommends for vinagre/remmina.
- Add recommends for gnome-remote-desktop for GNOME default
  pattern.
* Thu Dec 10 2020 Stasiek Michalski <stasiek@michalski.cc>
- Add malcontent-control recommendation to the base pattern
* Sat Sep  5 2020 Dominique Leuenberger <dleuenberger@suse.com>
- Drop a few suggests, making the DVD a bit smaller (no change on
  default installed systems):
  + dasher
  + gnome-backgrounds (50MB RPM)
  + python-gobject-devel
* Thu Apr 16 2020 Stefan Weiberg <sweiberg@suse.com>
- add gnome-packagekit recommends to gnome_basic pattern for SLE
  and Leap (bsc#1164858 and bsc#1081584)
* Sat Oct 26 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Drop NetworkManager-applet Recommends: We do not need this at all
  inside gnome-shell, we have had built-in tools for a long time.
* Fri Apr 26 2019 lnussel@suse.de
- Require gnome_basic instad of gnome_basis to get gnome-software
  etc (boo#1132777).
- Don't pull in gimp as it pulls in python2 which is deprecated
  (boo#1133307). KDE also doesn't install GIMP by default either.
* Wed Dec 12 2018 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend deja-dup: there are so many variants for
  users to maintain their backups (e.g. cloud storage) that
  deja-dup is no longer in the position of being unique.
  Additionally, we no longer need to pull in python2 on the default
  installation (boo#1119220).
* Sun Sep 30 2018 Stasiek Michalski <hellcp@mailbox.org>
- Change icons for Gnome Wayland and Gnome XOrg patterns.
  (boo#1039994)
* Wed Sep 19 2018 bjorn.lie@gmail.com
- Drop nautilus-eiciel Recommends.
* Wed Aug 22 2018 badshah400@gmail.com
- gnome_x11: Drop gnote; bijiben (another, more modern, note
  taking app) is already recommended by the same pattern.
* Mon Jun 25 2018 bjorn.lie@gmail.com
- Drop all traces of gconf:
  + Drop gconf-editor Suggests and Recommends.
  + Drop gconf2-branding-openSUSE Recommends.
  + Replace pulseaudio-module-gconf with
    pulseaudio-module-gsettings.
* Mon May 14 2018 fcrozat@suse.com
- Move gnome-shell-classic recommends to gnome_basis pattern
  (boo#1090117).
* Wed May  9 2018 dimstar@opensuse.org
- Move the gnome(wayland) pattern into the category of
  graphicalenvironments, aligning with the other DEs of the distro.
* Mon May  7 2018 dimstar@opensuse.org
- Re-add gnome-menus recommends to x11 pattern: gnome-menus still
  brings the .directory translations, which are shown in GNOME
  Activities (boo#1091487).
* Thu Apr 19 2018 fcrozat@suse.com
- Do not recommend pulseaudio-modules-lirc/bluetooth/zeroconf,
  use supplements in pulseaudio subpackages instead (bsc#1087207).
* Wed Apr 11 2018 fcrozat@suse.com
- Ensure x11_enhanced pattern is required by gnome_basis on SLE,
  not just x11 one (bsc#1084155).
* Tue Apr 10 2018 fcrozat@suse.com
- gnome-user-share is not available on all SLE flavors, only
  recommend it on SLE and keep require on openSUSE (bsc#1087222).
* Fri Apr  6 2018 fcrozat@suse.com
- Drop Recommends on caribou, it is no longer needed since
  GNOME 3.26.
- Enable gnome-multimedia pattern on SLE (bsc#1080203).
- Recommends gutenprint (bsc#1075136) on SLE.
- Improve description, icons and order for GNOME patterns
  (bsc#1062753, bsc#1080976).
- Remove totem-browser-plugin from Recommends, package no longer
  exists.
- Tune main gnome patterns order: first gnome_basic, then
  gnome_wayland then gnome_x11. gnome_basis doesn't need a order
  (not visible).
* Fri Apr  6 2018 lnussel@suse.de
- Do not pull in gnome-initial-setup on openSUSE (boo#1086056)
* Fri Apr  6 2018 dleuenberger@suse.com
- Drop gnome-icon-theme recommendation from gnome_x11: this theme
  has been long superseded by adwaita. While reworking the pattern
  for the SLE12->15 migration, it snuck back in.
* Wed Apr  4 2018 dimstar@opensuse.org
- Only recommend gnome-initial-setup on SLE/Leap: those have a
  crippled variant of g-i-s only doing extended keyboard settings.
  g-i-s in Tumbleweed is 'the real thing' and is meant for system
  integrators, that can use it as initial system start to configure
  the system.
* Fri Mar 23 2018 tchvatal@suse.com
- Drop dia and inkscape from defaults basically if you want to do
  vector operations you can install the packages while most users
  won't use these on default installation
* Thu Mar 22 2018 tchvatal@suse.com
- Drop the gnome-menus as it is dead as snail since 2013
* Wed Mar 21 2018 tchvatal@suse.com
- Reduce remmina/vino/vinagre to require only remmina/vingare
  as SLE/openSUSE diff, vino is VNC server not needed by default
  * kill gnome admin which is now empty
- Do not recommend amavisd-new - no need for virus scanner
- Drop google-droid-fonts, all core pkgs recommend required fonts
  no need to mess with it in patterns
- No longer recommend aria2
- Drop gutenprint and hplip from patterns here, this is handled
  by printing patterns
- Drop gnome-laptop pattern, move gnome-bluetooth recommend to
  core
- Drop gnome-imaging-opt moving dia to gnome-imaging
- Remove suggest on sound-juicer - rippers can install it by hand
- Remove abiword/gnumeric/pinpoint - we already pull full
  libreoffice, if someone wants to, they can pull it later on
- Switch from empathy to pidgin (also dropping the telepathy
  connectors) as the empathy is kinda dying while pidgin rocks
  on
* Wed Mar 21 2018 tchvatal@suse.com
- Bump version to $TODAY
- Remove libui-gtk-pkg as it is gone
- Remove various stray comments
- Drop gtk2-devel from devel as we should strive to kill it
- Drop gnome-doc-utils-devel as gnome-doc-utils is deprecated
- Drop monodevelop as we do not really emphasise mono these days
- Drop f-spot as it is gone
- Recommend also gstreamer-plugins-libav
- Drop yast-scanner and yast-tv as both modules were removed
* Mon Mar 12 2018 lnussel@suse.de
- Don't guard gnome pattern with %%is_opensuse (bsc#1084155)
* Wed Jan 24 2018 fcrozat@suse.com
- Split gnome pattern into gnome_x11 and gnome (wayland) patterns
  to implement SLED system roles (FATE#324198).
- Add gnome-user-share as requires (bsc#1075321).
* Thu Dec  7 2017 fcrozat@suse.com
- Add deja-dup, gnome-characters and gnome-contacts are Recommends
  to gnome pattern (SLE only) (bsc#1069699).
- Add brasero and file-roller as Recommends to gnome_basic pattern
  (SLE only) (bsc#1069699, bsc#1065945).
* Fri Nov 10 2017 fcrozat@suse.com
- Fix requires in gnome_basic pattern, it MUST be gnome_basic, not
  gnome-basic (bsc#1066771), pattern name MUST NOT contain -, only
  _ is allowed.
* Fri Nov  3 2017 fcrozat@suse.com
- Fix requires in gnome pattern on SLE, should be gnome-basic not
  gnome_basic.
* Tue Oct 31 2017 fcrozat@suse.com
- Stop requiring yast2-control-center-gnome in gnome pattern, use
  x11_yast patterns as Recommends instead (bsc#1062733).
- Remove gstreamer as Recommends, it is pulled by package
  dependencies.
- Stop provides/obsoletes openSUSE patterns when building on SLE.
- On SLE, gnome pattern requires gnome_basic and not just
  gnome_basis (bsc#1065166).
- No longer requires cheese for g-c-c user panel, only recommends.
- Switch to pidgin on SLE (bsc#1065191).
- Recommends gnome-documents on SLE gnome pattern.
- No longer recommends tracker-gui, it no longer exists.
- Recommends NetworkManager-openvpn/pptp/openconnect-gnome on SLE
  gnome pattern (bsc#1065148).
- Disable some implicit requires
  (gnome-shell/gnome-settings-daemon/gnome-control-center) when gdm
  is requires.
- Massive cleanup on gnome_basis pattern, dropping obsolete
  package dependencies.
- Add gnome_basic pattern, installing a basic GNOME desktop and
  application, with SLES as a use case.
* Tue Oct 17 2017 sflees@suse.de
- evince should be included on SLE (bsc#1063397)
* Tue Oct 10 2017 fcrozat@suse.com
- Do not requires x11_base pattern, it doesn't exist anymore and
  gnome_basis as requirement is enough.
* Mon Oct  9 2017 sflees@suse.de
- base pattern now obsoletes and provides Default to make SLE-12
  upgrades smoother (bsc#1062164)
* Thu Oct  5 2017 fcrozat@suse.com
- x11_base is required instead of desktop_base and enhanced_base for
  gnome pattern.
- Replace vinagre with Remmina and drop gftp (unmaintained
  upstream).
- Recommends gnome-session-wayland (bsc#1060638).
* Thu Oct  5 2017 aplazas@suse.com
- Add gnome-font-viewer recommendation to the gnome pattern.
* Wed Jul  5 2017 dimstar@opensuse.org
- Do not recommend gdb by gnome_basis: gdb alone does not give us
  useful bug reports; a reporter producing something useful still
  has to install all the -debuginfo packages and can as well
  install gdb.
* Thu Jun 22 2017 adrien.plazas@suse.com
- gnome_ide pattern:
  + Add the gnome-builder recommendation.
  + Add the gedit, gedit-plugins and jhbuild suggestions.
  + Move anjuta and monodevelop from recommendations to
    suggestions.
  + Move gitg from suggestions to recommendations.
* Tue Jun 20 2017 adrien.plazas@suse.com
- Remove liferea as it is not a GNOME application and is a niche
  tool that shouldn't be installed by default.
* Tue Jun 20 2017 adrien.plazas@suse.com
- Replace gucharmap by gnome-characters.
* Mon Jun 19 2017 dimstar@opensuse.org
- Do not require a base system: GNOME builds on top of X11 (for
  now) and what is below X11 is not our concern.
* Mon May 29 2017 dimstar@opensuse.org
- Change gnome_basis to be an internal-only pattern (non-visible).
* Wed May  3 2017 jengelh@inai.de
- Compact %%install routine; replace old RPM shell vars by macros.
* Sat Apr 29 2017 dimstar@opensuse.org
- Fixup supplements: the patterns no longer carry '-openSUSE' in
  the name.
* Thu Apr 27 2017 dimstar@opensuse.org
- Add gdk-pixbuf-thumbnailer and rsvg-thumbnailer recommends to
  gnome_utilities pattern (boo#1033650).
* Thu Mar 16 2017 sflees@suse.de
- Create new package from old unified patterns package
